# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vision.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cvision.proto\x12\x17magothy.protobuf.vision\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"]\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x01(\x02\x12\r\n\x05green\x18\x02 \x01(\x02\x12\x0c\n\x04\x62lue\x18\x03 \x01(\x02\x12*\n\x05\x61lpha\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xb5\x01\n\x0f\x46ramePrediction\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\x12\x12\n\nconfidence\x18\x05 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x06 \x01(\x05\x12\x12\n\nclass_name\x18\x07 \x01(\t\x12\x33\n\x0b\x63lass_color\x18\x08 \x01(\x0b\x32\x1e.magothy.protobuf.vision.Color\"\xc5\x01\n\x05\x46rame\x12\x14\n\x0c\x66rame_number\x18\x01 \x01(\x04\x12/\n\x0bttag_system\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x03 \x01(\x04\x12\x1e\n\x16prediction_duration_ms\x18\x04 \x01(\r\x12=\n\x0bpredictions\x18\x05 \x03(\x0b\x32(.magothy.protobuf.vision.FramePrediction\"\xf4\x04\n\x0cOccupancyMap\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x38\n\x04type\x18\x03 \x01(\x0e\x32*.magothy.protobuf.vision.OccupancyMap.Type\x12:\n\x05scope\x18\x0b \x01(\x0e\x32+.magothy.protobuf.vision.OccupancyMap.Scope\x12\x46\n\x0b\x63ompression\x18\x0c \x01(\x0e\x32\x31.magothy.protobuf.vision.OccupancyMap.Compression\x12\x0f\n\x07lat_deg\x18\x04 \x01(\x01\x12\x0f\n\x07lon_deg\x18\x05 \x01(\x01\x12\x12\n\ntl_lat_deg\x18\r \x01(\x01\x12\x12\n\ntl_lon_deg\x18\x0e \x01(\x01\x12\x12\n\nbr_lat_deg\x18\x0f \x01(\x01\x12\x12\n\nbr_lon_deg\x18\x10 \x01(\x01\x12\x0f\n\x07width_m\x18\x06 \x01(\x01\x12\x10\n\x08height_m\x18\x07 \x01(\x01\x12\x10\n\x08width_px\x18\x08 \x01(\r\x12\x11\n\theight_px\x18\t \x01(\r\x12\x0c\n\x04grid\x18\n \x01(\x0c\"8\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x0c\n\x08OCCUPIED\x10\x02\x12\n\n\x06MERGED\x10\x03\"\x1e\n\x05Scope\x12\t\n\x05LOCAL\x10\x00\x12\n\n\x06GLOBAL\x10\x01\";\n\x0b\x43ompression\x12\x07\n\x03RAW\x10\x00\x12\x06\n\x02GZ\x10\x01\x12\x08\n\x04ZSTD\x10\x02\x12\x08\n\x04JPEG\x10\x03\x12\x07\n\x03PNG\x10\x04\"\xc8\x02\n\x0bObjectTrack\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x10\n\x08track_id\x18\x03 \x01(\x05\x12\x11\n\tbranch_id\x18\x04 \x01(\x05\x12\x11\n\tsource_id\x18\x05 \x01(\x05\x12\r\n\x05\x61ge_s\x18\x06 \x01(\x02\x12\x14\n\x0cupdate_count\x18\x07 \x01(\x05\x12\x14\n\x0clatitude_deg\x18\x08 \x01(\x01\x12\x15\n\rlongitude_deg\x18\t \x01(\x01\x12\x13\n\x0bheading_deg\x18\n \x01(\x01\x12\x11\n\tspeed_mps\x18\x0b \x01(\x01\x12\x12\n\ncovariance\x18\x0c \x03(\x02\x12\x14\n\x0cis_confirmed\x18\r \x01(\x08\x12\x14\n\x0cis_predicted\x18\x0e \x01(\x08\"\xa3\x01\n\x0fObjectTrackList\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x11\n\tsource_id\x18\x03 \x01(\x05\x12\x34\n\x06tracks\x18\x04 \x03(\x0b\x32$.magothy.protobuf.vision.ObjectTrack\"5\n\x06Vertex\x12\x14\n\x0clatitude_deg\x18\x01 \x01(\x01\x12\x15\n\rlongitude_deg\x18\x02 \x01(\x01\"\x8b\x01\n\rTrackingFence\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x31\n\x08vertices\x18\x03 \x03(\x0b\x32\x1f.magothy.protobuf.vision.Vertexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vision_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COLOR']._serialized_start=106
  _globals['_COLOR']._serialized_end=199
  _globals['_FRAMEPREDICTION']._serialized_start=202
  _globals['_FRAMEPREDICTION']._serialized_end=383
  _globals['_FRAME']._serialized_start=386
  _globals['_FRAME']._serialized_end=583
  _globals['_OCCUPANCYMAP']._serialized_start=586
  _globals['_OCCUPANCYMAP']._serialized_end=1214
  _globals['_OCCUPANCYMAP_TYPE']._serialized_start=1065
  _globals['_OCCUPANCYMAP_TYPE']._serialized_end=1121
  _globals['_OCCUPANCYMAP_SCOPE']._serialized_start=1123
  _globals['_OCCUPANCYMAP_SCOPE']._serialized_end=1153
  _globals['_OCCUPANCYMAP_COMPRESSION']._serialized_start=1155
  _globals['_OCCUPANCYMAP_COMPRESSION']._serialized_end=1214
  _globals['_OBJECTTRACK']._serialized_start=1217
  _globals['_OBJECTTRACK']._serialized_end=1545
  _globals['_OBJECTTRACKLIST']._serialized_start=1548
  _globals['_OBJECTTRACKLIST']._serialized_end=1711
  _globals['_VERTEX']._serialized_start=1713
  _globals['_VERTEX']._serialized_end=1766
  _globals['_TRACKINGFENCE']._serialized_start=1769
  _globals['_TRACKINGFENCE']._serialized_end=1908
# @@protoc_insertion_point(module_scope)
